/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2021 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef NOAA_DOWNLOADER_HPP
#define NOAA_DOWNLOADER_HPP

struct METAR;
struct TAF;
class CurlGlobal;
class ProgressListener;
namespace Co { template<typename T> class Task; }

namespace NOAADownloader {

/**
 * Downloads a METAR from the NOAA server
 *
 * Throws on error.
 *
 * @param code Four letter code of the airport (upper case)
 */
Co::Task<METAR>
DownloadMETAR(const char *code, CurlGlobal &curl, ProgressListener &progress);

/**
 * Downloads a METAR from the NOAA server
 *
 * Throws on error.
 *
 * @param code Four letter code of the airport (upper case)
 */
Co::Task<TAF>
DownloadTAF(const char *code, CurlGlobal &curl,
            ProgressListener &progress);

} // namespace NOAADownloader

#endif
